@@ -726,7 +726,9 @@ void KQuickStyleItem::initStyleOption()
             qreal numOfSteps = (opt->maximum - opt->minimum) / opt->singleStep;
             // at least 5 pixels between tick marks
             qreal extent = horizontal() ? width() : height();
-            if (numOfSteps && (extent / numOfSteps < 5)) {
+            if (extent == 0) {
+                opt->tickInterval = 0;
+            } else if (numOfSteps && (extent / numOfSteps < 5)) {
                 opt->tickInterval = qRound((5 * numOfSteps / extent) + 0.5) * step();
             } else {
                 opt->tickInterval = opt->singleStep;
@@ -2073,10 +2075,6 @@ QSGNode *KQuickStyleItem::updatePaintNode(QSGNode *node, UpdatePaintNodeData *)
 void KQuickStyleItem::updatePolish()
 {
     if (isVisible() && width() >= 1 && height() >= 1) { // Note these are reals so 1 pixel is minimum
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 3)
-        // Need to request the focus reason every time, the signal is not entirely reliable: https://bugreports.qt.io/browse/QTBUG-125725
-        updateFocusReason();
-#endif
         const qreal devicePixelRatio = window() ? window()->effectiveDevicePixelRatio() : qApp->devicePixelRatio();
         const QSize size = QSize(m_textureWidth > 0 ? m_textureWidth : width(), m_textureHeight > 0 ? m_textureHeight : height()) * devicePixelRatio;
 
